##
##  file.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_api_c   5.45
%define       V_api_pl  0.96

#   package information
Name:         file
Summary:      Automatic File Content Type Recognition Tool
URL:          http://www.darwinsys.com/file/
Vendor:       Christos Zoulas
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Filesystem
License:      BSD
Version:      %{V_api_c}
Release:      20230728

#   package options
%option       with_perl  no

#   list of sources
Source0:      ftp://ftp.astron.com/pub/file/file-%{V_api_c}.tar.gz
Source1:      http://www.cpan.org/modules/by-module/File/File-LibMagic-%{V_api_pl}.tgz
Patch0:       file.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  zlib
PreReq:       zlib
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    The popular file(1) command which determines the type of a file by
    peeking at magic bytes of its content.

%track
    prog file = {
        version   = %{V_api_c}
        url       = ftp://ftp.astron.com/pub/file/
        regex     = file-(__VER__)\.tar\.gz
    }
    prog file:File-LibMagic = {
        version   = %{V_api_pl}
        url       = http://www.cpan.org/modules/by-module/File/
        regex     = File-LibMagic-(__VER__)\.tgz
    }

%prep
    %setup -q
    %setup -q -D -T -a 1
    %patch -p0

%build
    ACLOCAL=true \
    AUTOCONF=true \
    AUTOMAKE=true \
    AUTOHEADER=true \
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} %{l_cppflags}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --disable-shared
    %{l_make} %{l_mflags}
%if "%{with_perl}" == "yes"
    %{l_shtool} subst \
        -e 's;-I\.;-I. -I../src;g' \
        -e 's;-lmagic;-L../src/.libs -lmagic %{l_ldflags} -lz;' \
        File-LibMagic-%{V_api_pl}/Makefile.PL
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d File-LibMagic-%{V_api_pl} configure build
%endif

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d File-LibMagic-%{V_api_pl} install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

